package com.link.core.objeccache;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.alibaba.fastjson.serializer.SimplePropertyPreFilter;
import com.link.core.basic.model.BasicModel;
import com.link.core.basic.service.BasicService;
import com.link.core.util.PropertyUtil;
import com.link.core.util.RedisUtil;
import com.link.core.util.SpringUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.dynamicredis.DynamicRedisProps;
import com.link.core.util.dynamicredis.RedisSource;
import com.link.core.util.redisclient.LinkRedisClient;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class RedisCache {
   private static final Logger logger = LogManager.getLogger(RedisCache.class);
   private static final String exeFields = "page,rows,total,totalPage,startRow,endRow,totalFlag,pageFlag,onlyCountFlag,selectOneFlag,selectedFlag,reloadCache,lastId,exportTotal";

   public static String getCacheValue(String key, BasicService basicService, BasicModel entity, String queryFields, Class<? extends BasicModel> clz, int configVersion, String redisDbName) throws Exception {
      LinkRedisClient redisClient = null;
      String jsonStr = null;

      String var21;
      try {
         redisClient = RedisUtil.getJedis(getRedisDbNameByStr(redisDbName));
         if (redisClient.exists(key)) {
            String str = redisClient.get(key);
            Object object = JSON.parse(str);
            if (object instanceof JSONObject) {
               JSONObject jsonObject = (JSONObject)object;
               if (jsonObject.containsKey("version") && jsonObject.getInteger("version") == configVersion) {
                  String var12 = jsonObject.getString("list");
                  return var12;
               }
            }
         }

         List retList = basicService.queryByExamplePage(entity);
         if (retList.size() > 0) {
            SimplePropertyPreFilter filter = getFilterProperty(queryFields, clz);
            jsonStr = JSONObject.toJSONString(retList, filter, new SerializerFeature[0]);
            Map<String, Object> map = new HashMap();
            map.put("version", configVersion);
            map.put("list", jsonStr);
            redisClient.setex(key, getCacheTime(), JSONObject.toJSONString(map));
         }

         var21 = jsonStr;
      } catch (Exception var16) {
         Exception e = var16;
         e.printStackTrace();
         throw e;
      } finally {
         RedisUtil.returnResource(redisClient);
      }

      return var21;
   }

   public static String getCacheValueFromCache(String key, int configVersion, String redisDbName) throws Exception {
      LinkRedisClient redisClient = null;
      String jsonStr = null;

      try {
         redisClient = RedisUtil.getJedis(getRedisDbNameByStr(redisDbName));
         String str = redisClient.get(key);
         Object object = JSON.parse(str);
         if (object instanceof JSONObject) {
            JSONObject jsonObject = (JSONObject)object;
            if (jsonObject.containsKey("version") && jsonObject.getInteger("version") == configVersion) {
               jsonStr = jsonObject.getString("list");
            }
         }
      } catch (Exception var11) {
         Exception e = var11;
         throw e;
      } finally {
         RedisUtil.returnResource(redisClient);
      }

      return jsonStr;
   }

   public static RedisSource getRedisDbNameByStr(String redisDbName) throws Exception {
      logger.info("当前传入数据库名称：" + redisDbName);
      DynamicRedisProps dynamicRedisProps = (DynamicRedisProps)SpringUtil.getBean(DynamicRedisProps.class);
      if (!dynamicRedisProps.getEnable()) {
         logger.info("动态redis未启用！");
         return null;
      } else {
         RedisSource retRedisSource = null;
         RedisSource[] redisSources = RedisSource.values();
         RedisSource[] var4 = redisSources;
         int var5 = redisSources.length;

         for(int var6 = 0; var6 < var5; ++var6) {
            RedisSource redisSource = var4[var6];
            if (redisSource.getName().equals(redisDbName)) {
               retRedisSource = redisSource;
               break;
            }
         }

         if (!StringUtils.isBlank(redisDbName) && retRedisSource == null) {
            logger.error("检索不到对应的redis库名称，请检查！");
            throw new Exception("检索不到对应的redis库名称，请检查！");
         } else {
            if (retRedisSource == null) {
               retRedisSource = RedisSource.DEFAULT;
            }

            logger.info("最终选择的redis库为：" + retRedisSource.getName());
            return retRedisSource;
         }
      }
   }

   public static String getCacheValueFromDatabase(BasicService basicService, BasicModel entity, String queryFields, Class<? extends BasicModel> clz) throws Exception {
      try {
         SimplePropertyPreFilter filter = getFilterProperty(queryFields, clz);
         List retList = basicService.queryByExamplePage(entity);
         String jsonStr = JSONObject.toJSONString(retList, filter, new SerializerFeature[0]);
         return jsonStr;
      } catch (Exception var7) {
         Exception e = var7;
         throw e;
      }
   }

   public static SimplePropertyPreFilter getFilterProperty(String queryFields, Class<? extends BasicModel> clz) throws Exception {
      SimplePropertyPreFilter filter = new SimplePropertyPreFilter(clz, new String[0]);

      try {
         String[] var4;
         int var5;
         int var6;
         String in;
         String[] queryFieldsIn;
         if (!StringUtils.isBlank(queryFields)) {
            queryFieldsIn = queryFields.split(",");
            var4 = queryFieldsIn;
            var5 = queryFieldsIn.length;

            for(var6 = 0; var6 < var5; ++var6) {
               in = var4[var6];
               filter.getIncludes().add(in);
            }
         } else {
            queryFieldsIn = "page,rows,total,totalPage,startRow,endRow,totalFlag,pageFlag,onlyCountFlag,selectOneFlag,selectedFlag,reloadCache,lastId,exportTotal".split(",");
            var4 = queryFieldsIn;
            var5 = queryFieldsIn.length;

            for(var6 = 0; var6 < var5; ++var6) {
               in = var4[var6];
               filter.getExcludes().add(in);
            }
         }

         return filter;
      } catch (Exception var8) {
         Exception e = var8;
         throw e;
      }
   }

   public static int getCacheTime() throws Exception {
      if (ObjectCache.inputCacheExpire.get() != null) {
         return (Integer)ObjectCache.inputCacheExpire.get();
      } else {
         String expireStr = PropertyUtil.getProperty("OBJ_CACHE_EXPIRE", 0L);
         if (StringUtils.isBlank(expireStr)) {
            throw new Exception("未维护缓存时间参数！");
         } else {
            return Integer.parseInt(expireStr);
         }
      }
   }
}
